|
Boost-Commit : |
Subject: [Boost-commit] svn:boost r75559 - trunk/boost/chrono/io
From: vicente.botet_at_[hidden]
Date: 2011-11-19 15:53:59
Author: viboes
Date: 2011-11-19 15:53:58 EST (Sat, 19 Nov 2011)
New Revision: 75559
URL: http://svn.boost.org/trac/boost/changeset/75559
Log:
Chrono: change put by put_epoch/put_unit so that both facets could be merged lately.
Text files modified:
trunk/boost/chrono/io/duration_put.hpp | 2
trunk/boost/chrono/io/duration_units.hpp | 128 ++++++++++++++++++++--------------------
trunk/boost/chrono/io/time_point_put.hpp | 2
trunk/boost/chrono/io/time_point_units.hpp | 34 +++++-----
4 files changed, 83 insertions(+), 83 deletions(-)
Modified: trunk/boost/chrono/io/duration_put.hpp
==============================================================================
--- trunk/boost/chrono/io/duration_put.hpp (original)
+++ trunk/boost/chrono/io/duration_put.hpp 2011-11-19 15:53:58 EST (Sat, 19 Nov 2011)
@@ -225,7 +225,7 @@
iter_type put_unit(duration_units<CharT, OutputIterator> const& facet, iter_type s, std::ios_base& ios,
duration<Rep, Period> const& d) const
{
- return facet.put(s, ios, d);
+ return facet.put_unit(s, ios, d);
}
/**
Modified: trunk/boost/chrono/io/duration_units.hpp
==============================================================================
--- trunk/boost/chrono/io/time_point_put.hpp (original)
+++ trunk/boost/chrono/io/time_point_put.hpp 2011-11-19 15:53:58 EST (Sat, 19 Nov 2011)
@@ -266,7 +266,7 @@
template <typename Clock>
iter_type put_epoch(time_point_units<CharT, OutputIterator> const& facet, iter_type s, std::ios_base& ios) const
{
- return facet.template put<Clock> (s, ios);
+ return facet.template put_epoch<Clock> (s, ios);
}
/**
Modified: trunk/boost/chrono/io/time_point_units.hpp
==============================================================================
--- trunk/boost/chrono/io/time_point_units.hpp (original)
+++ trunk/boost/chrono/io/time_point_units.hpp 2011-11-19 15:53:58 EST (Sat, 19 Nov 2011)
@@ -69,14 +69,14 @@
* @param ios
* @Effects As if
* @code
- * return do_put(s, ios, Clock());
+ * return do_put_epoch(s, ios, Clock());
* @endcode
* @return @ s
*/
template <typename Clock>
- iter_type put(iter_type s, std::ios_base& ios) const
+ iter_type put_epoch(iter_type s, std::ios_base& ios) const
{
- return do_put(s, ios, Clock());
+ return do_put_epoch(s, ios, Clock());
}
/**
@@ -116,28 +116,28 @@
* @return
*/
virtual iter_type
- do_put(iter_type s, std::ios_base& ios, system_clock) const = 0;
+ do_put_epoch(iter_type s, std::ios_base& ios, system_clock) const = 0;
/**
* customization point for getting the system_clock timepoint's epoch.
*/
virtual std::basic_string<CharT> do_get_epoch(system_clock) const=0;
virtual iter_type
- do_put(iter_type s, std::ios_base& ios, steady_clock) const = 0;
+ do_put_epoch(iter_type s, std::ios_base& ios, steady_clock) const = 0;
virtual std::basic_string<CharT> do_get_epoch(steady_clock) const=0;
#if defined(BOOST_CHRONO_HAS_PROCESS_CLOCKS)
- virtual iter_type do_put(iter_type s, std::ios_base& ios, process_real_cpu_clock c) const =0;
+ virtual iter_type do_put_epoch(iter_type s, std::ios_base& ios, process_real_cpu_clock c) const =0;
virtual std::basic_string<CharT> do_get_epoch(process_real_cpu_clock) const=0;
- virtual iter_type do_put(iter_type s, std::ios_base& ios, process_user_cpu_clock c) const =0;
+ virtual iter_type do_put_epoch(iter_type s, std::ios_base& ios, process_user_cpu_clock c) const =0;
virtual std::basic_string<CharT> do_get_epoch(process_user_cpu_clock) const=0;
- virtual iter_type do_put(iter_type s, std::ios_base& ios, process_system_cpu_clock c) const =0;
+ virtual iter_type do_put_epoch(iter_type s, std::ios_base& ios, process_system_cpu_clock c) const =0;
virtual std::basic_string<CharT> do_get_epoch(process_system_cpu_clock) const=0;
- virtual iter_type do_put(iter_type s, std::ios_base& ios, process_cpu_clock c) const =0;
+ virtual iter_type do_put_epoch(iter_type s, std::ios_base& ios, process_cpu_clock c) const =0;
virtual std::basic_string<CharT> do_get_epoch(process_cpu_clock) const=0;
#endif
#if defined(BOOST_CHRONO_HAS_THREAD_CLOCK)
- virtual iter_type do_put(iter_type s, std::ios_base& ios, thread_clock c) const =0;
+ virtual iter_type do_put_epoch(iter_type s, std::ios_base& ios, thread_clock c) const =0;
virtual std::basic_string<CharT> do_get_epoch(thread_clock) const=0;
#endif
@@ -181,7 +181,7 @@
// }
- iter_type do_put(iter_type s, std::ios_base& , system_clock c) const
+ iter_type do_put_epoch(iter_type s, std::ios_base& , system_clock c) const
{
std::basic_string<CharT> str = do_get_epoch(c);
return std::copy(str.begin(), str.end(), s);
@@ -190,7 +190,7 @@
{
return clock_string<system_clock,CharT>::since();
}
- iter_type do_put(iter_type s, std::ios_base& , steady_clock c) const
+ iter_type do_put_epoch(iter_type s, std::ios_base& , steady_clock c) const
{
std::basic_string<CharT> str = do_get_epoch(c);
return std::copy(str.begin(), str.end(), s);
@@ -201,7 +201,7 @@
}
#if defined(BOOST_CHRONO_HAS_PROCESS_CLOCKS)
- iter_type do_put(iter_type s, std::ios_base& , process_real_cpu_clock c) const
+ iter_type do_put_epoch(iter_type s, std::ios_base& , process_real_cpu_clock c) const
{
std::basic_string<CharT> str = do_get_epoch(c);
return std::copy(str.begin(), str.end(), s);
@@ -210,7 +210,7 @@
{
return clock_string<process_real_cpu_clock,CharT>::since();
}
- iter_type do_put(iter_type s, std::ios_base& , process_user_cpu_clock c) const
+ iter_type do_put_epoch(iter_type s, std::ios_base& , process_user_cpu_clock c) const
{
std::basic_string<CharT> str = do_get_epoch(c);
return std::copy(str.begin(), str.end(), s);
@@ -219,7 +219,7 @@
{
return clock_string<process_user_cpu_clock,CharT>::since();
}
- iter_type do_put(iter_type s, std::ios_base& , process_system_cpu_clock c) const
+ iter_type do_put_epoch(iter_type s, std::ios_base& , process_system_cpu_clock c) const
{
std::basic_string<CharT> str = do_get_epoch(c);
return std::copy(str.begin(), str.end(), s);
@@ -228,7 +228,7 @@
{
return clock_string<process_system_cpu_clock,CharT>::since();
}
- iter_type do_put(iter_type s, std::ios_base& , process_cpu_clock c) const
+ iter_type do_put_epoch(iter_type s, std::ios_base& , process_cpu_clock c) const
{
std::basic_string<CharT> str = do_get_epoch(c);
return std::copy(str.begin(), str.end(), s);
@@ -240,7 +240,7 @@
#endif
#if defined(BOOST_CHRONO_HAS_THREAD_CLOCK)
- iter_type do_put(iter_type s, std::ios_base& , thread_clock c) const
+ iter_type do_put_epoch(iter_type s, std::ios_base& , thread_clock c) const
{
std::basic_string<CharT> str = do_get_epoch(c);
return std::copy(str.begin(), str.end(), s);
Boost-Commit list run by bdawes at acm.org, david.abrahams at rcn.com, gregod at cs.rpi.edu, cpdaniel at pacbell.net, john at johnmaddock.co.uk
--- trunk/boost/chrono/io/duration_units.hpp (original)
+++ trunk/boost/chrono/io/duration_units.hpp 2011-11-19 15:53:58 EST (Sat, 19 Nov 2011)
@@ -169,19 +169,19 @@
* @param ios
* @param d
* @Effects puts the unit associated to the duration @c d in @c s taken in account the @c ios state flags.
* The implementation uses the non template virtual function do_put as if
* @code
- * return do_put(s, ios, get_duration_style(ios), Period(), int_least64_t(d.count()));
+ * return do_put_unit(s, ios, get_duration_style(ios), Period(), int_least64_t(d.count()));
* @codeend
*
* where @get_duration_style gives the duration style associated to @ios.
* @return s
*/
template <typename Rep, typename Period>
- typename enable_if<is_localizable<Period> , iter_type>::type put(iter_type s, std::ios_base& ios,
+ typename enable_if<is_localizable<Period> , iter_type>::type put_unit(iter_type s, std::ios_base& ios,
duration<Rep, Period> const& d) const
{
- return do_put(s, ios, get_duration_style(ios), Period(), int_least64_t(d.count()));
+ return do_put_unit(s, ios, get_duration_style(ios), Period(), int_least64_t(d.count()));
}
/**
@@ -195,9 +195,9 @@
* @param ios
* @param d
* @Effects puts the unit associated to the duration @c d in @c s taken in account the @c ios state flags.
* The implementation uses the non template virtual function do_put as if
* @code
- * return do_put(s, ios, get_duration_style(ios), detail::rt_ratio(Period()), int_least64_t(d.count()));
+ * return do_put_unit(s, ios, get_duration_style(ios), detail::rt_ratio(Period()), int_least64_t(d.count()));
* @codeend
*
* where @get_duration_style gives the duration style associated to @ios and
@@ -205,10 +205,10 @@
* @return s
*/
template <typename Rep, typename Period>
- typename disable_if<is_localizable<Period> , iter_type>::type put(iter_type s, std::ios_base& ios,
+ typename disable_if<is_localizable<Period> , iter_type>::type put_unit(iter_type s, std::ios_base& ios,
duration<Rep, Period> const& d) const
{
- return do_put(s, ios, get_duration_style(ios), detail::rt_ratio(Period()), int_least64_t(d.count()));
+ return do_put_unit(s, ios, get_duration_style(ios), detail::rt_ratio(Period()), int_least64_t(d.count()));
}
/**
@@ -304,43 +304,43 @@
// used for ouput
virtual iter_type
- do_put(iter_type s, std::ios_base& ios, duration_style_type style, atto, int_least64_t) const = 0;
+ do_put_unit(iter_type s, std::ios_base& ios, duration_style_type style, atto, int_least64_t) const = 0;
virtual iter_type
- do_put(iter_type s, std::ios_base& ios, duration_style_type style, femto, int_least64_t) const = 0;
+ do_put_unit(iter_type s, std::ios_base& ios, duration_style_type style, femto, int_least64_t) const = 0;
virtual iter_type
- do_put(iter_type s, std::ios_base& ios, duration_style_type style, pico, int_least64_t) const = 0;
+ do_put_unit(iter_type s, std::ios_base& ios, duration_style_type style, pico, int_least64_t) const = 0;
virtual iter_type
- do_put(iter_type s, std::ios_base& ios, duration_style_type style, nano, int_least64_t) const = 0;
+ do_put_unit(iter_type s, std::ios_base& ios, duration_style_type style, nano, int_least64_t) const = 0;
virtual iter_type
- do_put(iter_type s, std::ios_base& ios, duration_style_type style, micro, int_least64_t) const = 0;
+ do_put_unit(iter_type s, std::ios_base& ios, duration_style_type style, micro, int_least64_t) const = 0;
virtual iter_type
- do_put(iter_type s, std::ios_base& ios, duration_style_type style, milli, int_least64_t) const = 0;
+ do_put_unit(iter_type s, std::ios_base& ios, duration_style_type style, milli, int_least64_t) const = 0;
virtual iter_type
- do_put(iter_type s, std::ios_base& ios, duration_style_type style, centi, int_least64_t) const = 0;
+ do_put_unit(iter_type s, std::ios_base& ios, duration_style_type style, centi, int_least64_t) const = 0;
virtual iter_type
- do_put(iter_type s, std::ios_base& ios, duration_style_type style, deci, int_least64_t) const = 0;
+ do_put_unit(iter_type s, std::ios_base& ios, duration_style_type style, deci, int_least64_t) const = 0;
virtual iter_type
- do_put(iter_type s, std::ios_base& ios, duration_style_type style, ratio<1> , int_least64_t) const = 0;
+ do_put_unit(iter_type s, std::ios_base& ios, duration_style_type style, ratio<1> , int_least64_t) const = 0;
virtual iter_type
- do_put(iter_type s, std::ios_base& ios, duration_style_type style, deca, int_least64_t) const = 0;
+ do_put_unit(iter_type s, std::ios_base& ios, duration_style_type style, deca, int_least64_t) const = 0;
virtual iter_type
- do_put(iter_type s, std::ios_base& ios, duration_style_type style, hecto, int_least64_t) const = 0;
+ do_put_unit(iter_type s, std::ios_base& ios, duration_style_type style, hecto, int_least64_t) const = 0;
virtual iter_type
- do_put(iter_type s, std::ios_base& ios, duration_style_type style, kilo, int_least64_t) const = 0;
+ do_put_unit(iter_type s, std::ios_base& ios, duration_style_type style, kilo, int_least64_t) const = 0;
virtual iter_type
- do_put(iter_type s, std::ios_base& ios, duration_style_type style, mega, int_least64_t) const = 0;
+ do_put_unit(iter_type s, std::ios_base& ios, duration_style_type style, mega, int_least64_t) const = 0;
virtual iter_type
- do_put(iter_type s, std::ios_base& ios, duration_style_type style, tera, int_least64_t) const = 0;
+ do_put_unit(iter_type s, std::ios_base& ios, duration_style_type style, tera, int_least64_t) const = 0;
virtual iter_type
- do_put(iter_type s, std::ios_base& ios, duration_style_type style, peta, int_least64_t) const = 0;
+ do_put_unit(iter_type s, std::ios_base& ios, duration_style_type style, peta, int_least64_t) const = 0;
virtual iter_type
- do_put(iter_type s, std::ios_base& ios, duration_style_type style, exa, int_least64_t) const = 0;
- virtual iter_type do_put(iter_type s, std::ios_base& ios, duration_style_type style, detail::rt_ratio,
+ do_put_unit(iter_type s, std::ios_base& ios, duration_style_type style, exa, int_least64_t) const = 0;
+ virtual iter_type do_put_unit(iter_type s, std::ios_base& ios, duration_style_type style, detail::rt_ratio,
int_least64_t) const = 0;
virtual iter_type
- do_put(iter_type s, std::ios_base& ios, duration_style_type style, ratio<60> , int_least64_t) const = 0;
+ do_put_unit(iter_type s, std::ios_base& ios, duration_style_type style, ratio<60> , int_least64_t) const = 0;
virtual iter_type
- do_put(iter_type s, std::ios_base& ios, duration_style_type style, ratio<3600> , int_least64_t) const = 0;
+ do_put_unit(iter_type s, std::ios_base& ios, duration_style_type style, ratio<3600> , int_least64_t) const = 0;
// used for input
virtual string_type do_get_plural_form(duration_style_type style, atto, std::size_t pf) const = 0;
@@ -404,123 +404,123 @@
return pattern;
}
- iter_type do_put(iter_type s, std::ios_base& ios, duration_style_type style, atto u, int_least64_t value) const
+ iter_type do_put_unit(iter_type s, std::ios_base& ios, duration_style_type style, atto u, int_least64_t value) const
{
string_type str = do_get_ratio_prefix(style, u);
std::copy(str.begin(), str.end(), s);
- return do_put(s, ios, style, ratio<1> (), value);
+ return do_put_unit(s, ios, style, ratio<1> (), value);
}
- iter_type do_put(iter_type s, std::ios_base& ios, duration_style_type style, femto u, int_least64_t value) const
+ iter_type do_put_unit(iter_type s, std::ios_base& ios, duration_style_type style, femto u, int_least64_t value) const
{
string_type str = do_get_ratio_prefix(style, u);
std::copy(str.begin(), str.end(), s);
- return do_put(s, ios, style, ratio<1> (), value);
+ return do_put_unit(s, ios, style, ratio<1> (), value);
}
- iter_type do_put(iter_type s, std::ios_base& ios, duration_style_type style, pico u, int_least64_t value) const
+ iter_type do_put_unit(iter_type s, std::ios_base& ios, duration_style_type style, pico u, int_least64_t value) const
{
string_type str = do_get_ratio_prefix(style, u);
std::copy(str.begin(), str.end(), s);
- return do_put(s, ios, style, ratio<1> (), value);
+ return do_put_unit(s, ios, style, ratio<1> (), value);
}
- iter_type do_put(iter_type s, std::ios_base& ios, duration_style_type style, nano u, int_least64_t value) const
+ iter_type do_put_unit(iter_type s, std::ios_base& ios, duration_style_type style, nano u, int_least64_t value) const
{
string_type str = do_get_ratio_prefix(style, u);
std::copy(str.begin(), str.end(), s);
- return do_put(s, ios, style, ratio<1> (), value);
+ return do_put_unit(s, ios, style, ratio<1> (), value);
}
- iter_type do_put(iter_type s, std::ios_base& ios, duration_style_type style, micro u, int_least64_t value) const
+ iter_type do_put_unit(iter_type s, std::ios_base& ios, duration_style_type style, micro u, int_least64_t value) const
{
string_type str = do_get_ratio_prefix(style, u);
std::copy(str.begin(), str.end(), s);
- return do_put(s, ios, style, ratio<1> (), value);
+ return do_put_unit(s, ios, style, ratio<1> (), value);
}
- iter_type do_put(iter_type s, std::ios_base& ios, duration_style_type style, milli u, int_least64_t value) const
+ iter_type do_put_unit(iter_type s, std::ios_base& ios, duration_style_type style, milli u, int_least64_t value) const
{
string_type str = do_get_ratio_prefix(style, u);
std::copy(str.begin(), str.end(), s);
- return do_put(s, ios, style, ratio<1> (), value);
+ return do_put_unit(s, ios, style, ratio<1> (), value);
}
- iter_type do_put(iter_type s, std::ios_base& ios, duration_style_type style, centi u, int_least64_t value) const
+ iter_type do_put_unit(iter_type s, std::ios_base& ios, duration_style_type style, centi u, int_least64_t value) const
{
string_type str = do_get_ratio_prefix(style, u);
std::copy(str.begin(), str.end(), s);
- return do_put(s, ios, style, ratio<1> (), value);
+ return do_put_unit(s, ios, style, ratio<1> (), value);
}
- iter_type do_put(iter_type s, std::ios_base& ios, duration_style_type style, deci u, int_least64_t value) const
+ iter_type do_put_unit(iter_type s, std::ios_base& ios, duration_style_type style, deci u, int_least64_t value) const
{
string_type str = do_get_ratio_prefix(style, u);
std::copy(str.begin(), str.end(), s);
- return do_put(s, ios, style, ratio<1> (), value);
+ return do_put_unit(s, ios, style, ratio<1> (), value);
}
- iter_type do_put(iter_type s, std::ios_base&, duration_style_type style, ratio<1> u, int_least64_t value) const
+ iter_type do_put_unit(iter_type s, std::ios_base&, duration_style_type style, ratio<1> u, int_least64_t value) const
{
string_type str = do_get_plural_form(style, u, do_get_plural_form(value));
return std::copy(str.begin(), str.end(), s);
}
- iter_type do_put(iter_type s, std::ios_base& ios, duration_style_type style, deca u, int_least64_t value) const
+ iter_type do_put_unit(iter_type s, std::ios_base& ios, duration_style_type style, deca u, int_least64_t value) const
{
string_type str = do_get_ratio_prefix(style, u);
std::copy(str.begin(), str.end(), s);
- return do_put(s, ios, style, ratio<1> (), value);
+ return do_put_unit(s, ios, style, ratio<1> (), value);
}
- iter_type do_put(iter_type s, std::ios_base& ios, duration_style_type style, hecto u, int_least64_t value) const
+ iter_type do_put_unit(iter_type s, std::ios_base& ios, duration_style_type style, hecto u, int_least64_t value) const
{
string_type str = do_get_ratio_prefix(style, u);
std::copy(str.begin(), str.end(), s);
- return do_put(s, ios, style, ratio<1> (), value);
+ return do_put_unit(s, ios, style, ratio<1> (), value);
}
- iter_type do_put(iter_type s, std::ios_base& ios, duration_style_type style, kilo u, int_least64_t value) const
+ iter_type do_put_unit(iter_type s, std::ios_base& ios, duration_style_type style, kilo u, int_least64_t value) const
{
string_type str = do_get_ratio_prefix(style, u);
std::copy(str.begin(), str.end(), s);
- return do_put(s, ios, style, ratio<1> (), value);
+ return do_put_unit(s, ios, style, ratio<1> (), value);
}
- iter_type do_put(iter_type s, std::ios_base& ios, duration_style_type style, mega u, int_least64_t value) const
+ iter_type do_put_unit(iter_type s, std::ios_base& ios, duration_style_type style, mega u, int_least64_t value) const
{
string_type str = do_get_ratio_prefix(style, u);
std::copy(str.begin(), str.end(), s);
- return do_put(s, ios, style, ratio<1> (), value);
+ return do_put_unit(s, ios, style, ratio<1> (), value);
}
- iter_type do_put(iter_type s, std::ios_base& ios, duration_style_type style, giga u, int_least64_t value) const
+ iter_type do_put_unit(iter_type s, std::ios_base& ios, duration_style_type style, giga u, int_least64_t value) const
{
string_type str = do_get_ratio_prefix(style, u);
std::copy(str.begin(), str.end(), s);
- return do_put(s, ios, style, ratio<1> (), value);
+ return do_put_unit(s, ios, style, ratio<1> (), value);
}
- iter_type do_put(iter_type s, std::ios_base& ios, duration_style_type style, tera u, int_least64_t value) const
+ iter_type do_put_unit(iter_type s, std::ios_base& ios, duration_style_type style, tera u, int_least64_t value) const
{
string_type str = do_get_ratio_prefix(style, u);
std::copy(str.begin(), str.end(), s);
- return do_put(s, ios, style, ratio<1> (), value);
+ return do_put_unit(s, ios, style, ratio<1> (), value);
}
- iter_type do_put(iter_type s, std::ios_base& ios, duration_style_type style, peta u, int_least64_t value) const
+ iter_type do_put_unit(iter_type s, std::ios_base& ios, duration_style_type style, peta u, int_least64_t value) const
{
string_type str = do_get_ratio_prefix(style, u);
std::copy(str.begin(), str.end(), s);
- return do_put(s, ios, style, ratio<1> (), value);
+ return do_put_unit(s, ios, style, ratio<1> (), value);
}
- iter_type do_put(iter_type s, std::ios_base& ios, duration_style_type style, exa u, int_least64_t value) const
+ iter_type do_put_unit(iter_type s, std::ios_base& ios, duration_style_type style, exa u, int_least64_t value) const
{
string_type str = do_get_ratio_prefix(style, u);
std::copy(str.begin(), str.end(), s);
- return do_put(s, ios, style, ratio<1> (), value);
+ return do_put_unit(s, ios, style, ratio<1> (), value);
}
- iter_type do_put(iter_type s, std::ios_base&, duration_style_type style, ratio<60> u, int_least64_t value) const
+ iter_type do_put_unit(iter_type s, std::ios_base&, duration_style_type style, ratio<60> u, int_least64_t value) const
{
string_type str = do_get_plural_form(style, u, do_get_plural_form(value));
return std::copy(str.begin(), str.end(), s);
}
- iter_type do_put(iter_type s, std::ios_base&, duration_style_type style, ratio<3600> u, int_least64_t value) const
+ iter_type do_put_unit(iter_type s, std::ios_base&, duration_style_type style, ratio<3600> u, int_least64_t value) const
{
string_type str = do_get_plural_form(style, u, do_get_plural_form(value));
return std::copy(str.begin(), str.end(), s);
}
- iter_type do_put(iter_type s, std::ios_base& ios, duration_style_type style, detail::rt_ratio rtr,
+ iter_type do_put_unit(iter_type s, std::ios_base& ios, duration_style_type style, detail::rt_ratio rtr,
int_least64_t value) const
{
*s++ = CharT('[');
@@ -529,7 +529,7 @@
std::use_facet<std::num_put<CharT, iter_type> >(ios.getloc()).put(s, ios, ' ', rtr.den);
*s++ = CharT(']');
- return do_put(s, ios, style, ratio<1> (), value);
+ return do_put_unit(s, ios, style, ratio<1> (), value);
}
string_type do_get_plural_form(duration_style_type style, ratio<1> , std::size_t pf) const
Modified: trunk/boost/chrono/io/time_point_put.hpp
@@ -169,19 +169,19 @@
* @param d
* @Effects puts the unit associated to the duration @c d in @c s taken in account the @c ios state flags.
- * The implementation uses the non template virtual function do_put as if
+ * The implementation uses the non template virtual function do_put_unit as if
* @code
@@ -195,9 +195,9 @@
* @param d
* @Effects puts the unit associated to the duration @c d in @c s taken in account the @c ios state flags.
- * The implementation uses the non template virtual function do_put as if
+ * The implementation uses the non template virtual function do_put_unit as if
* @code
==============================================================================